==> php82-nextcloud-26.0.5.tgz: share/nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given web address is not a valid URL" : "Zadaná web adresa nie je platná adresa URL",
    "The given legal notice address is too long" : "Zadaná adresa právneho upozornenia je príliš dlhá",
    "The given legal notice address is not a valid URL" : "Zadaná adresa právneho upozornenia nie je platná adresa URL",
    "The given privacy policy address is too long" : "Zadaná adresa zásady ochrany osobných údajov je príliš dlhá",
    "The given privacy policy address is not a valid URL" : "Zadaná adresa zásady ochrany osobných údajov nie je platná adresa URL",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "Saved" : "Uložené",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor sa nahral len čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload" : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používate vlastný motív vzhľadu. Predošlé nastavenia tým môžu byť prepísané.",
    "Theming" : "Zmena vzhľadu",
    "Appearance and accessibility" : "Vzhľad a správanie",
    "Dark theme with high contrast mode" : "Tmavá téma s vysokým kontrastom",
    "Enable dark high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "Similar to the high contrast mode, but with dark colours." : "Podobné ako v režime vysokého kontrastu, ale s tmavými farbami.",
    "Dark theme" : "Tmavý motív vzhľadu",
    "Enable dark theme" : "Zapnúť tmavý motív vzhľadu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tmavý motív pre uľahčenie očiam znížením celkovej svietivosti a jasu.",
    "System default theme" : "Predvolený vzhľad systému",
    "Enable the system default" : "Povoliť systémové nastavenia",
    "Using the default system appearance." : "Použitie predvoleného vzhľadu systému.",
    "Dyslexia font" : "Písmo pre dyslektikov",
    "Enable dyslexia font" : "Povoliť písmo pre dyslektikov",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou.",
    "High contrast mode" : "Režim vysokého kontrastu",
    "Enable high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mód s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
    "Light theme" : "Svetlá téma",
    "Enable the default light theme" : "Povoliť predvolený svetlý motív",
    "The default light appearance." : "Predvolený svetlý motív",
    "Legal notice" : "Právne upozornenie",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Adjust the Nextcloud theme" : "Upraviť motív vzhľadu Nextcloudu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Toto bude viditeľné pre všetkých klientov.",
    "Advanced options" : "Pokročilé možnosti",
    "Name" : "Názov",
    "Web link" : "Webový odkaz",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Legal notice link" : "Odkaz na právne upozornenie",
    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
    "Header logo" : "Logo v hlavičke",
    "Upload new header logo" : "Nahrať nové logo do hlavičky",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Nahrať novú ikonu webu",
    "User settings" : "Nastavenia užívateľa",
    "Keyboard shortcuts" : "Klávesové skratky",
    "Disable all keyboard shortcuts" : "Vypnúť všetky klávesové skratky",
    "Background" : "Pozadie",
    "Set a custom background" : "Nastaviť vlastné pozadie",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {guidelines}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaké problémy, neváhajte ich nahlásiť v {issuetracker}našom nástroji na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pridajte sa k {designteam}nášmu tímu dizajnérov{linkend}!",
    "Change color" : "Zmeniť farbu",
    "Theme selection is enforced" : "Vynucuje sa výber témy",
    "Reset to default" : "Nastaviť predvolené",
    "Upload" : "Nahrať",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Loading preview…" : "Načítavanie ukážky...",
    "Admin" : "Správca",
    "Error uploading the file" : "Chyba pri nahrávaní súboru",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V niektorých prípadoch môžu klávesové skratky zasahovať do nástrojov dostupnosti. Aby ste mohli správne zaostriť na svoj nástroj, môžete tu vypnúť všetky klávesové skratky. Tým sa tiež zakážu všetky dostupné skratky v aplikáciách.",
    "Pick from Files" : "Vybrať zo súborov",
    "Default image" : "Predvolený obrázok",
    "Custom color" : "Vlastná farba",
    "Plain background" : "Obyčajné pozadie",
    "Insert from {productName}" : "Vložiť z {productName}",
    "Open documentation" : "Otvoriť dokumentáciu",
    "https://…" : "https://...",
    "Upload new login background" : "Nahrať nové prihlasovacie pozadie",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ak chcete automaticky generovať favikony na základe nahraného loga a farby, nainštalujte rozšírenie Imagemagick PHP s podporou pre SVG obrázky."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given web address is not a valid URL" : "Zadaná web adresa nie je platná adresa URL",
    "The given legal notice address is too long" : "Zadaná adresa právneho upozornenia je príliš dlhá",
    "The given legal notice address is not a valid URL" : "Zadaná adresa právneho upozornenia nie je platná adresa URL",
    "The given privacy policy address is too long" : "Zadaná adresa zásady ochrany osobných údajov je príliš dlhá",
    "The given privacy policy address is not a valid URL" : "Zadaná adresa zásady ochrany osobných údajov nie je platná adresa URL",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "Saved" : "Uložené",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor sa nahral len čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload" : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používate vlastný motív vzhľadu. Predošlé nastavenia tým môžu byť prepísané.",
    "Theming" : "Zmena vzhľadu",
    "Appearance and accessibility" : "Vzhľad a správanie",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP modul „imagick“ nie je povolený, hoci tematická aplikácia áno. Aby generovanie favicon správne fungovalo, musíte nainštalovať a povoliť tento modul.",
    "Dark theme with high contrast mode" : "Tmavá téma s vysokým kontrastom",
    "Enable dark high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "Similar to the high contrast mode, but with dark colours." : "Podobné ako v režime vysokého kontrastu, ale s tmavými farbami.",
    "Dark theme" : "Tmavý motív vzhľadu",
    "Enable dark theme" : "Zapnúť tmavý motív vzhľadu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tmavý motív pre uľahčenie očiam znížením celkovej svietivosti a jasu.",
    "System default theme" : "Predvolený vzhľad systému",
    "Enable the system default" : "Povoliť systémové nastavenia",
    "Using the default system appearance." : "Použitie predvoleného vzhľadu systému.",
    "Dyslexia font" : "Písmo pre dyslektikov",
    "Enable dyslexia font" : "Povoliť písmo pre dyslektikov",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou.",
    "High contrast mode" : "Režim vysokého kontrastu",
    "Enable high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mód s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
    "Light theme" : "Svetlá téma",
    "Enable the default light theme" : "Povoliť predvolený svetlý motív",
    "The default light appearance." : "Predvolený svetlý motív",
    "Legal notice" : "Právne upozornenie",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Adjust the Nextcloud theme" : "Upraviť motív vzhľadu Nextcloudu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Vidieť ho budú všetci používatelia.",
    "Advanced options" : "Pokročilé možnosti",
    "Name" : "Názov",
    "Web link" : "Webový odkaz",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Background and login image" : "Obrázok pozadia a prihlasovacej obrazovky",
    "Legal notice link" : "Odkaz na právne upozornenie",
    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
    "Header logo" : "Logo v hlavičke",
    "Upload new header logo" : "Nahrať nové logo do hlavičky",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Nahrať novú ikonu webu",
    "User settings" : "Nastavenia užívateľa",
    "Disable user theming" : "Vypnúť úpravu vzhľadu používateľom",
    "Background" : "Pozadie",
    "Set a custom background" : "Nastaviť vlastné pozadie",
    "Keyboard shortcuts" : "Klávesové skratky",
    "Disable all keyboard shortcuts" : "Vypnúť všetky klávesové skratky",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {guidelines}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaké problémy, neváhajte ich nahlásiť v {issuetracker}našom nástroji na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pridajte sa k {designteam}nášmu tímu dizajnérov{linkend}!",
    "Move up" : "Presunúť hore",
    "Move down" : "Presunúť dole",
    "Change color" : "Zmeniť farbu",
    "Theme selection is enforced" : "Vynucuje sa výber témy",
    "Reset to default" : "Nastaviť predvolené",
    "Upload" : "Nahrať",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Select a custom color" : "Vyberte vlastnú farbu"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
